@@ -3,7 +3,7 @@ package Log::Saftpresse;
 use Moose;
 
 # ABSTRACT: a modular logfile analyzer
-our $VERSION = '1.5'; # VERSION
+our $VERSION = '1.6'; # VERSION
 
 use Log::Saftpresse::Log4perl;
 use Log::Saftpresse::Config;
@@ -13,6 +13,9 @@ use Log::Saftpresse::Slurp;
 use Log::Saftpresse::CounterOutputs;
 use Log::Saftpresse::Outputs;
 
+use Time::Piece;
+use Sys::Hostname;
+
 
 has 'config' => (
 	is => 'ro', isa => 'Log::Saftpresse::Config', lazy => 1,
@@ -87,12 +90,30 @@ sub _flushed_counters {
 	return;
 }
 
+sub saftpresse_version {
+  my $version = 'development';
+  eval '$version = $VERSION;'; ## no critic
+  return $version;
+}
+
+sub _startup_event {
+  my $self = shift;
+  my $version = $self->saftpresse_version;
+  return {
+    time => Time::Piece->new,
+    host => hostname(),
+    message => "saftpresse ($version) started",
+  };
+}
+
 
 sub run {
 	my $self = shift;
 	my $slurp = $self->slurp;
 	my $last_flush = time;
 
+  $self->outputs->output( $self->_startup_event );
+
 	$log->info('entering main loop');
 	for(;;) { # main loop
 		my $events;
@@ -134,7 +155,7 @@ Log::Saftpresse - a modular logfile analyzer
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 Description
 
